#!/usr/bin/env ruby
require 'net/imap'

#defaults
host = ENV['IMAP_HOST'] || ''
port = (ENV['IMAP_PORT'] || '143').to_i
use_ssl = !(ENV['IMAP_SSL'].nil?)
user = ENV['IMAP_USER'] || ''
password = ENV['IMAP_PASSWORD'] || ''
source_folder = ""
target_folder = ""
help_me = false

def imap_dump_folder(host, port, use_ssl, user, password, source_folder, target_folder)
  imap = Net::IMAP.new(host, port, use_ssl)
  imap.login(user, password)
  imap.select(source_folder)
  (1..imap.responses["EXISTS"][-1]).each do |mid|
    imap.copy(mid, target_folder)
    #imap.store(mid, "+FLAGS", [:Deleted])
  end
  #imap.expunge()
end

def usage(do_exit = true)
  STDERR.print "usage: #{$0} [options] source target
  --host=string        host server name
  --port=string        host server port
  --ssl                use ssl
  --user=string        username
  --password=string    password
  --help               show this message.
"
  exit if do_exit
end

ARGV.each do |option|
  case (option)
  when /^--host=(.+)/
    host = $1
  when /^--port=([0-9]+)/
    port = $1.to_i
  when /^--user=(.+)/
    user = $1
  when /^--password=(.+)/
    password = $1
  when /^--ssl/
    use_ssl = true
  when /^--help/
    help_me = true
  when /^(.+)/
    if (source_folder == '') then
      source_folder = $1
    elsif (target_folder == '') then
      target_folder = $1
    else
      usage()
    end
  else
    usage()
  end
end

if (host == "" or user == "" or password == "" or source_folder == "" or target_folder == "" or help_me == true) then
  usage(true)
end

imap_dump_folder(host, port, use_ssl, user, password, source_folder, target_folder)
